@@ -2,6 +2,8 @@
 
 # BSD 3-Clause License; see https://github.com/scikit-hep/uproot/blob/master/LICENSE
 
+from __future__ import absolute_import
+
 import copy
 import struct
 
@@ -13,6 +15,10 @@ class SimpleArray(object):
     def __init__(self, cls):
         self.cls = cls
 
+    @property
+    def __name__(self):
+        return "SimpleArray"
+
     def __repr__(self):
         if isinstance(self.cls, type):
             return "SimpleArray({0})".format(self.cls.__name__)
@@ -31,6 +37,10 @@ class STLVector(object):
     def __init__(self, cls):
         self.cls = cls
 
+    @property
+    def __name__(self):
+        return "STLVector"
+
     def __repr__(self):
         if isinstance(self.cls, type):
             return "STLVector({0})".format(self.cls.__name__)
@@ -57,6 +67,10 @@ class STLMap(object):
         self.keycls = keycls
         self.valcls = valcls
 
+    @property
+    def __name__(self):
+        return "STLMap"
+
     def __repr__(self):
         key = self.keycls.__name__ if isinstance(self.keycls, type) else repr(self.keycls)
         val = self.valcls.__name__ if isinstance(self.valcls, type) else repr(self.valcls)
@@ -95,6 +109,10 @@ class STLString(object):
             awkward = uproot.interp.interp.Interpretation.awkward
         self.awkward = awkward
 
+    @property
+    def __name__(self):
+        return "STLString"
+
     def __repr__(self):
         return "STLString()"
 
